package org.openepics.names.rest.beans.element;

import java.io.Serializable;
import java.util.Objects;
import java.util.UUID;

import io.swagger.v3.oas.annotations.media.Schema;

public class NameElementCommandCreate implements Serializable {

    /**
     *
     */
    private static final long serialVersionUID = -6805435306169229688L;

    @Schema(description = "Identity (uuid) for the system structure parent.")
    private UUID parentSystemStructure;
    @Schema(description = "Identity (uuid) for the device structure parent (if the name entry refers to device structure).")
    private UUID parentDeviceStructure;
    @Schema(description = "Index (instance) of the name entry (if the name entry refers to device structure).")
    private String index;
    @Schema(description = "Description of the name entry.")
    private String description;
    @Schema(description = "Comment of the name entry command.")
    private String comment;

    /**
     * Public constructor.
     */
    public NameElementCommandCreate() {
    }

    /**
     * Public constructor.
     *
     * @param parentSystemStructure parent system structure uuid
     * @param parentDeviceStructure parent device structure uuid
     * @param index index
     * @param description description
     * @param comment comment
     */
    public NameElementCommandCreate(
            UUID parentSystemStructure, UUID parentDeviceStructure, String index,
            String description, String comment) {
        super();
        this.parentSystemStructure = parentSystemStructure;
        this.parentDeviceStructure = parentDeviceStructure;
        this.index = index;
        this.description = description;
        this.comment = comment;
    }

    public UUID getParentSystemStructure() {
        return parentSystemStructure;
    }
    public void setParentSystemStructure(UUID parentSystemStructure) {
        this.parentSystemStructure = parentSystemStructure;
    }
    public UUID getParentDeviceStructure() {
        return parentDeviceStructure;
    }
    public void setParentDeviceStructure(UUID parentDeviceStructure) {
        this.parentDeviceStructure = parentDeviceStructure;
    }
    public String getIndex() {
        return index;
    }
    public void setIndex(String index) {
        this.index = index;
    }
    public String getDescription() {
        return description;
    }
    public void setDescription(String description) {
        this.description = description;
    }
    public String getComment() {
        return comment;
    }
    public void setComment(String comment) {
        this.comment = comment;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;

        return equals ((NameElementCommandCreate) obj);
    }

    public boolean equals(NameElementCommandCreate other) {
        if (other == null)
            return false;

        if (!super.equals(other)) {
            return false;
        }

        if (getParentSystemStructure() == null) {
            if (other.getParentSystemStructure() != null)
                return false;
        } else if (!getParentSystemStructure().equals(other.getParentSystemStructure()))
            return false;
        if (getParentDeviceStructure() == null) {
            if (other.getParentDeviceStructure() != null)
                return false;
        } else if (!getParentDeviceStructure().equals(other.getParentDeviceStructure()))
            return false;
        if (getIndex() == null) {
            if (other.getIndex() != null)
                return false;
        } else if (!getIndex().equals(other.getIndex()))
            return false;
        if (getDescription() == null) {
            if (other.getDescription() != null)
                return false;
        } else if (!getDescription().equals(other.getDescription()))
            return false;
        if (getComment() == null) {
            if (other.getComment() != null)
                return false;
        } else if (!getComment().equals(other.getComment()))
            return false;

        return true;
    }

    @Override
    public int hashCode() {
        return Objects.hash(
                getParentSystemStructure(), getParentDeviceStructure(), getIndex(),
                getDescription(), getComment());
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        sb.append("\"parentSystemStructure\": " + getParentSystemStructure());
        sb.append(", \"parentDeviceStructure\": " + getParentDeviceStructure());
        sb.append(", \"index\": "                 + getIndex());
        sb.append(", \"description\": "           + getDescription());
        sb.append(", \"comment\": "               + getComment());
        sb.append("}");
        return sb.toString();
    }

}
